==> openjdk7-src-7.u99_2.6.5-1-armv7h.pkg.tar.xz: com/sun/swing/internal/plaf/basic/resources/basic_sv.java <==
package com.sun.swing.internal.plaf.basic.resources;

import java.util.ListResourceBundle;

public final class basic_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AbstractButton.click.textAndMnemonic", "klicka" },
            { "AbstractDocument.addition.textAndMnemonic", "till\u00E4gg" },
            { "AbstractDocument.deletion.textAndMnemonic", "borttagning" },
            { "AbstractDocument.redo.textAndMnemonic", "G\u00F6r om" },
            { "AbstractDocument.styleChange.textAndMnemonic", "format\u00E4ndring" },
            { "AbstractDocument.undo.textAndMnemonic", "\u00C5ngra" },
            { "AbstractUndoableEdit.redo.textAndMnemonic", "G\u00F6r om" },
            { "AbstractUndoableEdit.undo.textAndMnemonic", "\u00C5ngra" },
            { "ColorChooser.cancel.textAndMnemonic", "Avbryt" },
            { "ColorChooser.cmyk.textAndMnemonic", "C&MYK" },
            { "ColorChooser.cmykAlpha.textAndMnemonic", "Alfa" },
            { "ColorChooser.cmykBlack.textAndMnemonic", "Svart" },
            { "ColorChooser.cmykCyan.textAndMnemonic", "Cyan" },
            { "ColorChooser.cmykMagenta.textAndMnemonic", "Magenta" },
            { "ColorChooser.cmykYellow.textAndMnemonic", "Gul" },
            { "ColorChooser.hsl.textAndMnemonic", "HS&L" },
            { "ColorChooser.hslHue.textAndMnemonic", "Nyans" },
            { "ColorChooser.hslLightness.textAndMnemonic", "Ljusstyrka" },
            { "ColorChooser.hslSaturation.textAndMnemonic", "M\u00E4ttnad" },
            { "ColorChooser.hslTransparency.textAndMnemonic", "Transparens" },
            { "ColorChooser.hsv.textAndMnemonic", "&HSV" },
            { "ColorChooser.hsvHue.textAndMnemonic", "Nyans" },
            { "ColorChooser.hsvSaturation.textAndMnemonic", "M\u00E4ttnad" },
            { "ColorChooser.hsvTransparency.textAndMnemonic", "Transparens" },
            { "ColorChooser.hsvValue.textAndMnemonic", "V\u00E4rde" },
            { "ColorChooser.ok.textAndMnemonic", "OK" },
            { "ColorChooser.preview.textAndMnemonic", "Granska" },
            { "ColorChooser.reset.textAndMnemonic", "&\u00C5terst\u00E4ll" },
            { "ColorChooser.rgb.textAndMnemonic", "R&GB" },
            { "ColorChooser.rgbAlpha.textAndMnemonic", "Alfa" },
            { "ColorChooser.rgbBlue.textAndMnemonic", "&Bl\u00E5" },
            { "ColorChooser.rgbGreen.textAndMnemonic", "Gr\u00F6&n" },
            { "ColorChooser.rgbHexCode.textAndMnemonic", "&F\u00E4rgkod" },
            { "ColorChooser.rgbRed.textAndMnemonic", "R\u00F6&d" },
            { "ColorChooser.sample.textAndMnemonic", "Exempeltext  Exempeltext" },
            { "ColorChooser.swatches.textAndMnemonic", "&Prov" },
            { "ColorChooser.swatchesRecent.textAndMnemonic", "Senaste:" },
            { "ComboBox.togglePopup.textAndMnemonic", "v\u00E4xlaPopup" },
            { "FileChooser.acceptAllFileFilter.textAndMnemonic", "Alla filer" },
            { "FileChooser.cancelButton.textAndMnemonic", "Avbryt" },
            { "FileChooser.cancelButtonToolTip.textAndMnemonic", "Avbryt filvalsdialogruta" },
            { "FileChooser.directoryDescription.textAndMnemonic", "Katalog" },
            { "FileChooser.directoryOpenButton.textAndMnemonic", "&\u00D6ppna" },
            { "FileChooser.directoryOpenButtonToolTip.textAndMnemonic", "\u00D6ppna vald katalog" },
            { "FileChooser.fileDescription.textAndMnemonic", "Generisk fil" },
            { "FileChooser.fileSizeGigaBytes", "{0} GB" },
            { "FileChooser.fileSizeKiloBytes", "{0} KB" },
            { "FileChooser.fileSizeMegaBytes", "{0} MB" },
            { "FileChooser.filesDetailsAccessibleName", "Fildetaljer" },
            { "FileChooser.filesListAccessibleName", "Fillista" },
            { "FileChooser.helpButton.textAndMnemonic", "&Hj\u00E4lp" },
            { "FileChooser.helpButtonToolTip.textAndMnemonic", "Hj\u00E4lp - Filv\u00E4ljare" },
            { "FileChooser.newFolderError.textAndMnemonic", "Fel uppstod n\u00E4r ny mapp skapades" },
            { "FileChooser.newFolderErrorSeparator", ":" },
            { "FileChooser.newFolderParentDoesntExist.textAndMnemonic", "Kan inte skapa mappen.\n\nSystemet kan inte hitta angiven s\u00F6kv\u00E4g." },
            { "FileChooser.newFolderParentDoesntExistTitle.textAndMnemonic", "Kan inte skapa mappen" },
            { "FileChooser.openButton.textAndMnemonic", "&\u00D6ppna" },
            { "FileChooser.openButtonToolTip.textAndMnemonic", "\u00D6ppna vald fil" },
            { "FileChooser.openDialogTitle.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.other.newFolder", "Ny mapp" },
            { "FileChooser.other.newFolder.subsequent", "Ny mapp.{0}" },
            { "FileChooser.renameError.textAndMnemonic", "Kan inte namn\u00E4ndra {0}" },
            { "FileChooser.renameErrorFileExists.textAndMnemonic", "Kan inte namn\u00E4ndra {0}: En fil med angivet namn finns redan. Ange ett annat filnamn. " },
            { "FileChooser.renameErrorTitle.textAndMnemonic", "Ett fel intr\u00E4ffade vid f\u00F6rs\u00F6k att \u00E4ndra namn p\u00E5 fil eller mapp" },
            { "FileChooser.saveButton.textAndMnemonic", "&Spara" },
            { "FileChooser.saveButtonToolTip.textAndMnemonic", "Spara vald fil" },
            { "FileChooser.saveDialogTitle.textAndMnemonic", "Spara" },
            { "FileChooser.updateButton.textAndMnemonic", "Upp&datera" },
            { "FileChooser.updateButtonToolTip.textAndMnemonic", "Uppdatera kataloglistan" },
            { "FileChooser.win32.newFolder", "Ny mapp" },
            { "FileChooser.win32.newFolder.subsequent", "Ny mapp ({0})" },
            { "FormView.browseFileButton.textAndMnemonic", "Bl\u00E4ddra..." },
            { "FormView.resetButton.textAndMnemonic", "\u00C5terst\u00E4ll" },
            { "FormView.submitButton.textAndMnemonic", "Skicka fr\u00E5ga" },
            { "InternalFrame.closeButtonToolTip", "St\u00E4ng" },
            { "InternalFrame.iconButtonToolTip", "Minimera" },
            { "InternalFrame.maxButtonToolTip", "Maximera" },
            { "InternalFrame.restoreButtonToolTip", "\u00C5terst\u00E4ll" },
            { "InternalFrameTitlePane.closeButton.textAndMnemonic", "St\u00E4ng" },
            { "InternalFrameTitlePane.closeButtonAccessibleName", "St\u00E4ng" },
            { "InternalFrameTitlePane.iconifyButtonAccessibleName", "Minimera" },
            { "InternalFrameTitlePane.maximizeButton.textAndMnemonic", "Maximera" },
            { "InternalFrameTitlePane.maximizeButtonAccessibleName", "Maximera" },
            { "InternalFrameTitlePane.minimizeButton.textAndMnemonic", "Minimera" },
            { "InternalFrameTitlePane.moveButton.textAndMnemonic", "Flytta" },
            { "InternalFrameTitlePane.restoreButton.textAndMnemonic", "\u00C5terst\u00E4ll" },
            { "InternalFrameTitlePane.sizeButton.textAndMnemonic", "Storlek" },
            { "IsindexView.prompt", "Detta \u00E4r ett s\u00F6kbart index. Ange s\u00F6kord:" },
            { "OptionPane.cancelButton.textAndMnemonic", "Avbryt" },
            { "OptionPane.inputDialog.titleAndMnemonic", "Indata" },
            { "OptionPane.messageDialog.titleAndMnemonic", "Meddelande" },
            { "OptionPane.noButton.textAndMnemonic", "&Nej" },
            { "OptionPane.okButton.textAndMnemonic", "OK" },
            { "OptionPane.title.textAndMnemonic", "V\u00E4lj ett alternativ" },
            { "OptionPane.yesButton.textAndMnemonic", "&Ja" },
            { "PrintingDialog.abortButton.textAndMnemonic", "&Avbryt" },
            { "PrintingDialog.abortButtonToolTip.textAndMnemonic", "Avbryt utskrift" },
            { "PrintingDialog.contentAborting.textAndMnemonic", "Utskriften avbryts..." },
            { "PrintingDialog.contentInitial.textAndMnemonic", "Utskrift p\u00E5g\u00E5r..." },
            { "PrintingDialog.contentProgress.textAndMnemonic", "Utskriven sida {0}..." },
            { "PrintingDialog.titleAborting.textAndMnemonic", "Skriver ut (avbryter)" },
            { "PrintingDialog.titleProgress.textAndMnemonic", "Skriver ut" },
            { "ProgressMonitor.progress.textAndMnemonic", "P\u00E5g\u00E5r..." },
            { "SplitPane.leftButton.textAndMnemonic", "v\u00E4nster knapp" },
            { "SplitPane.rightButton.textAndMnemonic", "h\u00F6ger knapp" },
        };
    }
}

==> openjdk7-src-7.u131_2.6.9-1-armv7h.pkg.tar.xz: com/sun/swing/internal/plaf/basic/resources/basic_sv.java <==
package com.sun.swing.internal.plaf.basic.resources;

import java.util.ListResourceBundle;

public final class basic_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AbstractButton.click.textAndMnemonic", "klicka" },
            { "AbstractDocument.addition.textAndMnemonic", "till\u00E4gg" },
            { "AbstractDocument.deletion.textAndMnemonic", "borttagning" },
            { "AbstractDocument.redo.textAndMnemonic", "G\u00F6r om" },
            { "AbstractDocument.styleChange.textAndMnemonic", "format\u00E4ndring" },
            { "AbstractDocument.undo.textAndMnemonic", "\u00C5ngra" },
            { "AbstractUndoableEdit.redo.textAndMnemonic", "G\u00F6r om" },
            { "AbstractUndoableEdit.undo.textAndMnemonic", "\u00C5ngra" },
            { "ColorChooser.cancel.textAndMnemonic", "Avbryt" },
            { "ColorChooser.cmyk.textAndMnemonic", "C&MYK" },
            { "ColorChooser.cmykAlpha.textAndMnemonic", "Alfa" },
            { "ColorChooser.cmykBlack.textAndMnemonic", "Svart" },
            { "ColorChooser.cmykCyan.textAndMnemonic", "Cyan" },
            { "ColorChooser.cmykMagenta.textAndMnemonic", "Magenta" },
            { "ColorChooser.cmykYellow.textAndMnemonic", "Gul" },
            { "ColorChooser.hsl.textAndMnemonic", "HS&L" },
            { "ColorChooser.hslHue.textAndMnemonic", "Nyans" },
            { "ColorChooser.hslLightness.textAndMnemonic", "Ljusstyrka" },
            { "ColorChooser.hslSaturation.textAndMnemonic", "M\u00E4ttnad" },
            { "ColorChooser.hslTransparency.textAndMnemonic", "Transparens" },
            { "ColorChooser.hsv.textAndMnemonic", "&HSV" },
            { "ColorChooser.hsvHue.textAndMnemonic", "Nyans" },
            { "ColorChooser.hsvSaturation.textAndMnemonic", "M\u00E4ttnad" },
            { "ColorChooser.hsvTransparency.textAndMnemonic", "Transparens" },
            { "ColorChooser.hsvValue.textAndMnemonic", "V\u00E4rde" },
            { "ColorChooser.ok.textAndMnemonic", "OK" },
            { "ColorChooser.preview.textAndMnemonic", "Granska" },
            { "ColorChooser.reset.textAndMnemonic", "&\u00C5terst\u00E4ll" },
            { "ColorChooser.rgb.textAndMnemonic", "R&GB" },
            { "ColorChooser.rgbAlpha.textAndMnemonic", "Alfa" },
            { "ColorChooser.rgbBlue.textAndMnemonic", "&Bl\u00E5" },
            { "ColorChooser.rgbGreen.textAndMnemonic", "Gr\u00F6&n" },
            { "ColorChooser.rgbHexCode.textAndMnemonic", "&F\u00E4rgkod" },
            { "ColorChooser.rgbRed.textAndMnemonic", "R\u00F6&d" },
            { "ColorChooser.sample.textAndMnemonic", "Exempeltext  Exempeltext" },
            { "ColorChooser.swatches.textAndMnemonic", "&Prov" },
            { "ColorChooser.swatchesRecent.textAndMnemonic", "Senaste:" },
            { "ComboBox.togglePopup.textAndMnemonic", "v\u00E4xlaPopup" },
            { "FileChooser.acceptAllFileFilter.textAndMnemonic", "Alla filer" },
            { "FileChooser.cancelButton.textAndMnemonic", "Avbryt" },
            { "FileChooser.cancelButtonToolTip.textAndMnemonic", "Avbryt filvalsdialogruta" },
            { "FileChooser.directoryDescription.textAndMnemonic", "Katalog" },
            { "FileChooser.directoryOpenButton.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.directoryOpenButtonToolTip.textAndMnemonic", "\u00D6ppna vald katalog" },
            { "FileChooser.fileDescription.textAndMnemonic", "Generisk fil" },
            { "FileChooser.fileSizeGigaBytes", "{0} GB" },
            { "FileChooser.fileSizeKiloBytes", "{0} KB" },
            { "FileChooser.fileSizeMegaBytes", "{0} MB" },
            { "FileChooser.filesDetailsAccessibleName", "Fildetaljer" },
            { "FileChooser.filesListAccessibleName", "Fillista" },
            { "FileChooser.helpButton.textAndMnemonic", "&Hj\u00E4lp" },
            { "FileChooser.helpButtonToolTip.textAndMnemonic", "Hj\u00E4lp - Filv\u00E4ljare" },
            { "FileChooser.newFolderError.textAndMnemonic", "Fel uppstod n\u00E4r ny mapp skapades" },
            { "FileChooser.newFolderErrorSeparator", ":" },
            { "FileChooser.newFolderParentDoesntExist.textAndMnemonic", "Kan inte skapa mappen.\n\nSystemet kan inte hitta angiven s\u00F6kv\u00E4g." },
            { "FileChooser.newFolderParentDoesntExistTitle.textAndMnemonic", "Kan inte skapa mappen" },
            { "FileChooser.openButton.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.openButtonToolTip.textAndMnemonic", "\u00D6ppna vald fil" },
            { "FileChooser.openDialogTitle.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.other.newFolder", "Ny mapp" },
            { "FileChooser.other.newFolder.subsequent", "Ny mapp.{0}" },
            { "FileChooser.renameError.textAndMnemonic", "Kan inte namn\u00E4ndra {0}" },
            { "FileChooser.renameErrorFileExists.textAndMnemonic", "Kan inte namn\u00E4ndra {0}: En fil med angivet namn finns redan. Ange ett annat filnamn. " },
            { "FileChooser.renameErrorTitle.textAndMnemonic", "Ett fel intr\u00E4ffade vid f\u00F6rs\u00F6k att \u00E4ndra namn p\u00E5 fil eller mapp" },
            { "FileChooser.saveButton.textAndMnemonic", "Spara" },
            { "FileChooser.saveButtonToolTip.textAndMnemonic", "Spara vald fil" },
            { "FileChooser.saveDialogTitle.textAndMnemonic", "Spara" },
            { "FileChooser.updateButton.textAndMnemonic", "Upp&datera" },
            { "FileChooser.updateButtonToolTip.textAndMnemonic", "Uppdatera kataloglistan" },
            { "FileChooser.win32.newFolder", "Ny mapp" },
            { "FileChooser.win32.newFolder.subsequent", "Ny mapp ({0})" },
            { "FormView.browseFileButton.textAndMnemonic", "Bl\u00E4ddra..." },
            { "FormView.resetButton.textAndMnemonic", "\u00C5terst\u00E4ll" },
            { "FormView.submitButton.textAndMnemonic", "Skicka fr\u00E5ga" },
            { "InternalFrame.closeButtonToolTip", "St\u00E4ng" },
            { "InternalFrame.iconButtonToolTip", "Minimera" },
            { "InternalFrame.maxButtonToolTip", "Maximera" },
            { "InternalFrame.restoreButtonToolTip", "\u00C5terst\u00E4ll" },
            { "InternalFrameTitlePane.closeButton.textAndMnemonic", "&St\u00E4ng" },
            { "InternalFrameTitlePane.closeButtonAccessibleName", "St\u00E4ng" },
            { "InternalFrameTitlePane.iconifyButtonAccessibleName", "Minimera" },
            { "InternalFrameTitlePane.maximizeButton.textAndMnemonic", "Ma&ximera" },
            { "InternalFrameTitlePane.maximizeButtonAccessibleName", "Maximera" },
            { "InternalFrameTitlePane.minimizeButton.textAndMnemonic", "Mi&nimera" },
            { "InternalFrameTitlePane.moveButton.textAndMnemonic", "&Flytta" },
            { "InternalFrameTitlePane.restoreButton.textAndMnemonic", "&\u00C5terst\u00E4ll" },
            { "InternalFrameTitlePane.sizeButton.textAndMnemonic", "&Storlek" },
            { "IsindexView.prompt", "Detta \u00E4r ett s\u00F6kbart index. Ange s\u00F6kord:" },
            { "OptionPane.cancelButton.textAndMnemonic", "Avbryt" },
            { "OptionPane.inputDialog.titleAndMnemonic", "Indata" },
            { "OptionPane.messageDialog.titleAndMnemonic", "Meddelande" },
            { "OptionPane.noButton.textAndMnemonic", "&Nej" },
            { "OptionPane.okButton.textAndMnemonic", "OK" },
            { "OptionPane.title.textAndMnemonic", "V\u00E4lj ett alternativ" },
            { "OptionPane.yesButton.textAndMnemonic", "&Ja" },
            { "PrintingDialog.abortButton.textAndMnemonic", "&Avbryt" },
            { "PrintingDialog.abortButtonToolTip.textAndMnemonic", "Avbryt utskrift" },
            { "PrintingDialog.contentAborting.textAndMnemonic", "Utskriften avbryts..." },
            { "PrintingDialog.contentInitial.textAndMnemonic", "Utskrift p\u00E5g\u00E5r..." },
            { "PrintingDialog.contentProgress.textAndMnemonic", "Utskriven sida {0}..." },
            { "PrintingDialog.titleAborting.textAndMnemonic", "Skriver ut (avbryter)" },
            { "PrintingDialog.titleProgress.textAndMnemonic", "Skriver ut" },
            { "ProgressMonitor.progress.textAndMnemonic", "P\u00E5g\u00E5r..." },
            { "SplitPane.leftButton.textAndMnemonic", "v\u00E4nster knapp" },
            { "SplitPane.rightButton.textAndMnemonic", "h\u00F6ger knapp" },
        };
    }
}
